Crate virt_arena
virt_
arena
0.3.0
All Items
Crate Items
Structs
Crate
virt_
arena
Structs

Virt
Arena
A memory arena which leverages the virtual memory system for allocating structures in a single contiguous memory region.